@@ -37,6 +37,7 @@ OC.L10N.register(
     "Accept" : "Asantiñ",
     "Remove" : "Lemel",
     "email" : "postel",
+    "Choose target folder" : "Dibab an teuliad moned",
     "Important info" : "Titouroù pouezus",
     "Other" : "All",
     "Forward" : "War-raok",
@@ -44,9 +45,11 @@ OC.L10N.register(
     "Show images" : "Diskouzh ar skeudennoù",
     "Message frame" : "Fram kemenadenn",
     "Move" : "Diplasañ",
-    "Loading …" : "O Kargañ ...",
     "Remove account" : "Lemel ar c'hont",
-    "Quota" : "Quota",
+    "Folder name" : "Anv teuliad",
+    "Loading …" : "O Kargañ ...",
+    "The folder and all messages in it will be deleted." : "An teuliad a pep kemenadenn enhañ a vo lamet",
+    "Delete folder" : "Diverkañ an teuliad",
     "Delete folder {name}" : "Lemel an teuliad {folderid}",
     "Rename" : "Adenvel",
     "Clear cache" : "Gwalc'hiñ ar c'hache",
