@@ -230,6 +230,7 @@ OC.L10N.register(
     "Remove" : "Fjern",
     "email" : "e-mail",
     "Loading messages …" : "Indlæser beskeder...",
+    "Choose target folder" : "Vælg destinationsmappe",
     "No more submailboxes in here" : "Ikke flere underpostkasser herinde",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Beskeder vil automatisk blive markeret som vigtige baseret på, hvilke meddelelser du har interageret med eller markeret som vigtige. I begyndelsen skal du muligvis manuelt ændre vigtigheden for at lære systemet, men det vil forbedres med tiden.",
     "Important info" : "Vigtig information",
@@ -257,21 +258,24 @@ OC.L10N.register(
     "Moving" : "Flytter",
     "Moving thread" : "Flytter tråd",
     "Moving message" : "Flytter besked",
-    "Loading …" : "Indlæser…",
-    "Not supported by the server" : "Ikke understøttet af serveren",
-    "{usage} of {limit} used" : "{usage} af {limit} brugt",
     "Remove account" : "Fjern konto",
     "Remove {email}" : "Fjern {email}",
-    "Quota" : "Kvote",
+    "Add folder" : "Tilføj mappe",
+    "Folder name" : "Mappenavn",
     "Saving" : "Gemmer",
     "Move up" : "Flyt op",
     "Move down" : "Flyt ned",
-    "Collapse mailboxes" : "Skjul postkasser ",
+    "Show all folders" : "Vis alle mapper",
+    "Collapse folders" : "Fold mapper sammen",
     "_{total} message_::_{total} messages_" : ["{total} besked","{total} beskeder"],
+    "Loading …" : "Indlæser…",
     "Clear mailbox {name}" : "Ryd postkasse {name}",
+    "Delete folder" : "Slet mappe",
     "Mark all as read" : "Markér alle som læst",
     "Mark all messages of this folder as read" : "Markér alle beskeder i denne mappe som læst",
+    "Add subfolder" : "Tilføj undermappe",
     "Rename" : "Omdøb",
+    "Move folder" : "Flyt mappe",
     "Clear cache" : "Ryd cache",
     "Subscribed" : "Abonneret",
     "Sync in background" : "Synkroniser i baggrunden",
@@ -404,6 +408,7 @@ OC.L10N.register(
     "Add mailbox" : "Tilføj postkasse",
     "Show all subscribed mailboxes" : "Vis alle postkasser der abonneres på",
     "Show all mailboxes" : "Vis alle postkasser",
+    "Collapse mailboxes" : "Skjul postkasser ",
     "Clear mailbox" : "Ryd postkasse",
     "Mark all messages of this mailbox as read" : "Markér alle beskeder i denne postkasse som læst",
     "Add submailbox" : "Tilføj underpostkasse",
