@@ -145,7 +145,6 @@ OC.L10N.register(
     "Mailvelope" : "Mailvelope",
     "Mailvelope is enabled for the current domain!" : "¡Mailvelope se encuentra habilitado para el dominio actual!",
     "Looking for a way to encrypt your emails?" : "¿Buscas una forma de cifrar tus correos electrónicos?",
-    "Install Mailvelope browser extension by clicking here" : "Instala la extensión del navegador Mailvelope haciendo clic aquí",
     "Enable Mailvelope for the current domain" : "Habilita Mailvelope para el dominio actual",
     "Assistance features" : "Características de asistencia",
     "About" : "Acerca",
@@ -318,13 +317,15 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
     "Quoted text" : "Texto citado",
     "Move" : "Mover",
-    "Loading …" : "Cargando …",
     "Remove account" : "Eliminar cuenta",
-    "Quota" : "Cuota",
+    "Add folder" : "Agregar carpeta",
+    "Folder name" : "Nombre de la carpeta",
     "Saving" : "Guardando",
     "Move up" : "Mover arriba",
     "Move down" : "Mover abajo",
     "Show all folders" : "Mostrar todas las carpetas",
+    "Collapse folders" : "Compactar carpetas",
+    "Loading …" : "Cargando …",
     "Delete folder" : "Eliminar carpeta",
     "Mark all as read" : "Marcar todos como leídos",
     "Rename" : "Renombrar",
@@ -393,6 +394,7 @@ OC.L10N.register(
     "The link leads to %s" : "La liga lleva a %s",
     "Continue to %s" : "Continuar a %s",
     "Mailbox search" : "Búsqueda en el buzón de correo",
+    "Install Mailvelope browser extension by clicking here" : "Instala la extensión del navegador Mailvelope haciendo clic aquí",
     "No messages in this mailbox" : "No hay mensajes en este buzón de correo",
     "No trash mailbox configured" : "No se ha configurado un buzón de papelera",
     "Draft: " : "Borrador:",
