@@ -145,7 +145,7 @@ OC.L10N.register(
     "Mailvelope" : "Mailvelope",
     "Mailvelope is enabled for the current domain!" : "Mailvelope gaituta dago uneko domeinurako!",
     "Looking for a way to encrypt your emails?" : "Zure mezu elektronikoak enkriptatzeko modu bat bilatzen ari zara?",
-    "Install Mailvelope browser extension by clicking here" : "Instalatu Mailvelope arakatzailearen luzapena hemen klik eginez",
+    "Install Mailvelope browser extension" : "Instalatu Mailvelope arakatzailearen luzapena",
     "Enable Mailvelope for the current domain" : "Gaitu Mailvelope uneko domeinurako",
     "Assistance features" : "Laguntzailearen aukerak",
     "About" : "Honi buruz",
@@ -373,15 +373,11 @@ OC.L10N.register(
     "Moving" : "Mugitzen",
     "Moving thread" : "Haria mugitzen",
     "Moving message" : "Mezua mugitzen",
-    "Loading …" : "Kargatzen...",
-    "Not supported by the server" : "Zerbitzariak ez du onartzen",
-    "{usage} of {limit} used" : "{usage} / {limit} erabilita",
     "Remove account" : "Kendu kontua",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email} kontua eta cachean gordetako posta datuak Nextcloudetik ezabatu egingo dira, baina ez zure posta hornitzailetik.",
     "Remove {email}" : "Kendu {email}",
     "Provisioned account is disabled" : "Hornitutako kontua desgaituta dago",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Mesedez, hasi saioa pasahitz bat erabiliz kontu hau gaitzeko. Uneko saioa pasahitzik gabeko autentifikazioa erabiltzen ari da, adibidez. SSO edo WebAuthn.",
-    "Quota" : "Kuota",
     "Show only subscribed folders" : "Erakutsi harpidetutako karpetak soilik",
     "Add folder" : "Gehitu karpeta",
     "Folder name" : "Karpetaren izena",
@@ -390,9 +386,10 @@ OC.L10N.register(
     "Move down" : "Eraman behera",
     "Show all subscribed folders" : "Erakutsi harpidetutako karpeta guztiak",
     "Show all folders" : "Erakutsi karpeta guztiak",
-    "Collapse mailboxes" : "Tolestu postontziak",
+    "Collapse folders" : "Bildu karpetak",
     "_{total} message_::_{total} messages_" : ["Mezu {total}","{total} mezu"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} irakurri gabe {total} -etik","{unread} irakurri gabe {total} -etik"],
+    "Loading …" : "Kargatzen...",
     "All messages in mailbox will be deleted." : "Postontziko mezu guztiak ezabatuko dira.",
     "Clear mailbox {name}" : "Garbitu {name} postontzia",
     "The folder and all messages in it will be deleted." : " \nKarpeta eta bertan dauden mezu guztiak ezabatuko dira.",
@@ -745,6 +742,7 @@ OC.L10N.register(
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Orrialde hori bisitatu nahi ez baduzu, itzul dezakezu <a href=\"%s\">Mail </a>-ra.",
     "Continue to %s" : "Jarraitu hona: %s",
     "Mailbox search" : "Postontziko bilaketa",
+    "Install Mailvelope browser extension by clicking here" : "Instalatu Mailvelope arakatzailearen luzapena hemen klik eginez",
     "No messages in this mailbox" : "Mezurik ez postontzi honetan",
     "No trash mailbox configured" : "Ez da zakarrontzirik konfiguratu",
     "Draft: " : "Zirriborroa: ",
@@ -757,6 +755,7 @@ OC.L10N.register(
     "Mailbox name" : "Postontziaren izena",
     "Show all subscribed mailboxes" : "Erakutsi harpidetutako postontzi guztiak",
     "Show all mailboxes" : "Erakutsi postontzi guztiak",
+    "Collapse mailboxes" : "Tolestu postontziak",
     "Clear mailbox" : "Garbitu postontzia",
     "The mailbox and all messages in it will be deleted." : "Postontzia eta bertan dauden mezu guztiak ezabatuko dira.",
     "Delete mailbox" : "Ezabatu postontzia",
