@@ -95,6 +95,7 @@ OC.L10N.register(
     "Trusted senders" : "Luotetut lähettäjät",
     "Manage S/MIME certificates" : "Hallitse S/MIME-varmenteita",
     "Looking for a way to encrypt your emails?" : "Etsitkö tapaa salata sähköpostisi?",
+    "Install Mailvelope browser extension" : "Asenna Mailvelope-selainlaajennus",
     "About" : "Tietoja",
     "Keyboard shortcuts" : "Pikanäppäimet",
     "Compose new message" : "Uusi viesti",
@@ -271,13 +272,9 @@ OC.L10N.register(
     "Moving" : "Siirretään",
     "Moving thread" : "Siirretään ketjua",
     "Moving message" : "Siirretään viestiä",
-    "Loading …" : "Ladataan…",
-    "Not supported by the server" : "Ei tuettu palvelimen toimesta",
-    "{usage} of {limit} used" : "{usage}/{limit} käytetty",
     "Remove account" : "Poista tili",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Tili {email} ja tallennetut viesti poistetaan Nextcloudista, muttei sähköpostintarjoajaltasi.",
     "Remove {email}" : "Poista {email}",
-    "Quota" : "Kiintiö",
     "Show only subscribed folders" : "Näytä vain tilatut kansiot",
     "Add folder" : "Lisää kansio",
     "Folder name" : "Kansion nimi",
@@ -286,9 +283,10 @@ OC.L10N.register(
     "Move down" : "Siirrä alas",
     "Show all subscribed folders" : "Näytä kaikki tilatut kansiot",
     "Show all folders" : "Näytä kaikki kansiot",
-    "Collapse mailboxes" : "Supista postilaatikot",
+    "Collapse folders" : "Supista kansiot",
     "_{total} message_::_{total} messages_" : ["{total} viesti","{total} viestiä"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lukematonta {total} viestistä","{unread} lukematonta {total} viestistä"],
+    "Loading …" : "Ladataan…",
     "All messages in mailbox will be deleted." : "Kaikki postilaatikon viestit poistetaan.",
     "Clear mailbox {name}" : "Tyhjennä postilaatikko {name}",
     "The folder and all messages in it will be deleted." : "Tämä kansio ja kaikki sen viestit poistetaan.",
@@ -503,6 +501,7 @@ OC.L10N.register(
     "Add mailbox" : "Lisää postilaatikko",
     "Show all subscribed mailboxes" : "Näytä kaikki tilatut postilaatikot",
     "Show all mailboxes" : "Näytä kaikki postilaatikot",
+    "Collapse mailboxes" : "Supista postilaatikot",
     "Clear mailbox" : "Tyhjennä postilaatikko",
     "The mailbox and all messages in it will be deleted." : "Tämä postilaatikko ja kaikki sen viestit poistetaan.",
     "Delete mailbox" : "Poista postilaatikko",
