@@ -151,11 +151,8 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "התמונות נחסמו כדי להגן על הפרטיות שלך",
     "Message frame" : "מסגרת הודעה",
     "Move" : "העברה",
-    "Loading …" : "בטעינה",
-    "Not supported by the server" : "לא נתמך על ידי השרת",
     "Remove account" : "הסרת חשבון",
     "Remove {email}" : "להסיר את {email}",
-    "Quota" : "מכיסה",
     "Show only subscribed folders" : "להציג תיקיות שבמינוי בלבד",
     "Add folder" : "הוספת תיקייה",
     "Folder name" : "שם התיקייה",
@@ -163,9 +160,10 @@ OC.L10N.register(
     "Move down" : "להוריד למטה",
     "Show all subscribed folders" : "להציג את כל התיקיות שבמינוי",
     "Show all folders" : "הצגת כל התיקיות",
-    "Collapse mailboxes" : "צמצום תיבות דוא״ל",
+    "Collapse folders" : "קיווץ תיקיות",
     "_{total} message_::_{total} messages_" : ["הודעה אחת","{total} הודעות","{total} הודעות"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["אחת לא נקראה מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}"],
+    "Loading …" : "בטעינה",
     "Delete folder" : "מחק תיקייה",
     "An error occurred, unable to rename the mailbox." : "אירעה שגיאה, לא ניתן לשנות את שם תיבת הדוא״ל.",
     "Mark all as read" : "סימון הכול כנקרא",
@@ -273,6 +271,7 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "ההודעות שלך מסודרות באינדקס. פעולה זו עשויה לארוך זמן מה בתיבות דואר גדולות.",
     "Add mailbox" : "הוספת תיבת דוא״ל",
     "Show all mailboxes" : "הצגת כל תיבות הדוא״ל",
+    "Collapse mailboxes" : "צמצום תיבות דוא״ל",
     "The mailbox and all messages in it will be deleted." : "תיבת הדוא״ל על כל ההודעות שבה תימחק.",
     "Delete mailbox" : "מחיקת תיבת דוא״ל",
     "Delete mailbox {name}" : "מחיקת תיבת הדוא״ל {name}",
