@@ -189,13 +189,9 @@ OC.L10N.register(
     "Moving" : "Premještanje",
     "Moving thread" : "Premještanje dretve",
     "Moving message" : "Premještanje poruke",
-    "Loading …" : "Učitavanje…",
-    "Not supported by the server" : "Ne podržava poslužitelj",
-    "{usage} of {limit} used" : "{usage} od {limit} iskorišteno",
     "Remove account" : "Izbriši račun",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Račun za {email} i podaci e-pošte spremljeni u predmemoriji uklonit će se iz Nextclouda, ali ne iz vašeg davatelja usluga e-pošte.",
     "Remove {email}" : "Ukloni {email}",
-    "Quota" : "Kvota",
     "Show only subscribed folders" : "Prikaži samo pretplaćene mape",
     "Add folder" : "Dodaj mapu",
     "Folder name" : "Naziv mape",
@@ -204,9 +200,10 @@ OC.L10N.register(
     "Move down" : "Premjesti dolje",
     "Show all subscribed folders" : "Prikaži sve pretplaćene mape",
     "Show all folders" : "Prikaži sve mape",
-    "Collapse mailboxes" : "Sakrij sandučiće",
+    "Collapse folders" : "Sakrij mape",
     "_{total} message_::_{total} messages_" : ["{total} poruka","{total} poruka","{total} poruka"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nepročitana od {total}","{unread} nepročitane od {total}","{unread} nepročitanih od {total}"],
+    "Loading …" : "Učitavanje…",
     "The folder and all messages in it will be deleted." : "Izbrisat će se mapa i sve poruke.",
     "Delete folder" : "Izbriši mapu",
     "Delete folder {name}" : "Izbriši mapu {name}",
@@ -387,6 +384,7 @@ OC.L10N.register(
     "Add mailbox" : "Dodaj sandučić",
     "Show all subscribed mailboxes" : "Prikaži sve pretplaćene sandučiće",
     "Show all mailboxes" : "Prikaži sve sandučiće",
+    "Collapse mailboxes" : "Sakrij sandučiće",
     "The mailbox and all messages in it will be deleted." : "Izbrisat će se sandučić i sve pripadajuće poruke.",
     "Delete mailbox" : "Izbriši sandučić",
     "Delete mailbox {name}" : "Izbriši sandučić {name}",
