@@ -187,20 +187,16 @@ OC.L10N.register(
     "Moving" : "Tramudende",
     "Moving thread" : "Tramudende sa dibata",
     "Moving message" : "Tramudende su messàgiu",
-    "Loading …" : "Carrrighende …",
-    "Not supported by the server" : "No suportadu dae su serbidore",
-    "{usage} of {limit} used" : "{usage} de {limit} impreadu",
     "Remove account" : "Boga·nche contu",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Su contu pro {email} e is datos de posta eletrònica allogados in sa memòria temporànea s'ant a bogare dae Nextcloud, ma no dae su frunidore de posta eletrònica tuo.",
     "Remove {email}" : "Boga•nche {email}",
-    "Quota" : "Cuota",
     "Folder name" : "Nùmene de sa cartella",
     "Saving" : "Sarvende",
     "Move up" : "Tràmuda fache a susu",
     "Move down" : "Tràmuda fache a bàsciu",
-    "Collapse mailboxes" : "Istringhe is casellas de posta",
     "_{total} message_::_{total} messages_" : ["{total} messàgios","{total} messàgios"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} non lèghidos de {total}","{unread} unread of {total}"],
+    "Loading …" : "Carrrighende …",
     "Delete folder" : "Cantzella sa cartella",
     "An error occurred, unable to rename the mailbox." : "B'at àpidu un'errore, no at fatu a torrare a numenare sa casella de posta.",
     "Mark all as read" : "Marca totu comente lèghidu",
@@ -357,6 +353,7 @@ OC.L10N.register(
     "Add mailbox" : "Agiunghe casella de posta",
     "Show all subscribed mailboxes" : "Mustra totu is casellas de posta sutascritas",
     "Show all mailboxes" : "Mustra totu is casellas de posta",
+    "Collapse mailboxes" : "Istringhe is casellas de posta",
     "The mailbox and all messages in it will be deleted." : "Sa casella de posta e is messàgios chi cuntenet ant a èssere cantzellados.",
     "Delete mailbox" : "Cantzella casella de posta",
     "Delete mailbox {name}" : "Cantzella casella de posta {name}",
