@@ -80,6 +80,7 @@ OC.L10N.register(
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Låt appen samla in data om dina interaktioner. Baserat på denna information kommer appen att anpassas till dina preferenser. Uppgifterna lagras endast lokalt.",
     "Trusted senders" : "Betrodda avsändare",
     "Looking for a way to encrypt your emails?" : "Söker du efter ett sätt att kryptera meddelanden?",
+    "Install Mailvelope browser extension" : "Installera webbläsartillägget Mailvelope",
     "About" : "Om",
     "Keyboard shortcuts" : "Tangentbordsgenvägar",
     "Compose new message" : "Skapa nytt meddelande",
@@ -220,12 +221,8 @@ OC.L10N.register(
     "Moving" : "Flyttar",
     "Moving thread" : "Flyttar tråd",
     "Moving message" : "Flyttar meddelande",
-    "Loading …" : "Läser in ...",
-    "Not supported by the server" : "Stöds ej av  servern",
-    "{usage} of {limit} used" : "{usage} av {limit} använt",
     "Remove account" : "Ta bort konto",
     "Remove {email}" : "Ta bort {email}",
-    "Quota" : "Kvot",
     "Show only subscribed folders" : "Visa endast mappar som du prenumererar på",
     "Add folder" : "Lägg till mapp",
     "Folder name" : "Mappnamn",
@@ -234,9 +231,10 @@ OC.L10N.register(
     "Move down" : "Flytta ner",
     "Show all subscribed folders" : "Visa alla mappar som du prenumererar på",
     "Show all folders" : "Visa alla kataloger",
-    "Collapse mailboxes" : "Minimera brevlådor",
+    "Collapse folders" : "Dölj mappar",
     "_{total} message_::_{total} messages_" : ["{total} meddelande","{total} meddelanden"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} av {total} oläst","{unread} av {total} oläst"],
+    "Loading …" : "Läser in ...",
     "The folder and all messages in it will be deleted." : "Denna mapp och alla meddelanden i den kommer att raderas.",
     "Delete folder" : "Radera mapp",
     "Delete folder {name}" : "Ta bort mapp {name}",
@@ -389,6 +387,7 @@ OC.L10N.register(
     "Add mailbox" : "Lägg till brevlåda",
     "Show all subscribed mailboxes" : "Visa alla prenumererade brevlådor",
     "Show all mailboxes" : "Visa alla brevlådor",
+    "Collapse mailboxes" : "Minimera brevlådor",
     "Delete mailbox" : "Radera brevlåda",
     "Mark all messages of this mailbox as read" : "Markera alla meddelanden i den här brevlådan som lästa",
     "Search in mailbox" : "Sök i brevlådan",
