@@ -8,6 +8,7 @@ OC.L10N.register(
     "Mail" : "Msururu wa maduka",
     "Sign in with Google" : "Ingia kwa Google",
     "Save" : "Hifadhi",
+    "Connect" : "Unganisha",
     "Auto" : "Auto",
     "Name" : "Jina",
     "Password" : "Nenosiri",
@@ -28,6 +29,7 @@ OC.L10N.register(
     "Delete" : "Futa",
     "Search" : "Tafuta",
     "Send" : "Tuma",
+    "Refresh" : "Refresh",
     "From" : "Tangu/ kutoka",
     "To" : "Mpaka/ hadi",
     "Choose" : "Chagua",
@@ -70,7 +72,9 @@ OC.L10N.register(
     "Folder name" : "Jina la kisanduku",
     "Loading …" : "Inapakia",
     "Delete folder" : "Futa kisanduku",
+    "Mark all as read" : "Mark all as read",
     "Rename" : "Ipe jina jipya",
+    "Clear cache" : "Clear cache",
     "Subscribed" : "Iliyojisajili",
     "Edit message" : "Hariri ujumbe",
     "Draft" : "Draft",
@@ -82,17 +86,21 @@ OC.L10N.register(
     "Show more" : "Show more",
     "Clear" : "Futa",
     "Close" : "Funga",
+    "Body" : "Body",
     "Date" : "Tarehe",
     "Tags" : "Maoni",
     "Select tags" : "Chagua ukumbusho",
     "Last 7 days" : "Siku 7 zilizopita",
     "Custom" : "Mteja",
+    "Add tag" : "Add tag",
     "Not found" : "Haipatikani",
     "Mark as unread" : "Weka alama kama haijasomwa",
     "Mark as read" : "Weka alama kama iliyosomwa",
     "Copy translated text" : "Nakili maandishi yaliyotafsiriwa",
     "Untitled event" : "Tukio lisilotajwa",
     "(organizer)" : "(Mratibu)",
+    "Operator" : "Operator",
+    "contains" : "contains",
     "matches" : "matches",
     "Priority" : "Kipaumbele",
     "Reset" : "Pangilia upya",
