@@ -5,21 +5,21 @@ OC.L10N.register(
     "Personal" : "Personal",
     "Later" : "Keyinchalik",
     "Mail" : "Mail",
-    "Save" : "Save",
+    "Save" : "Saqlash",
     "Connect" : "Connect",
     "Name" : "Name",
     "Password" : "Password",
-    "None" : "None",
+    "None" : "Yo'q",
     "Email address" : "E-pochta manzili",
-    "Cancel" : "Cancel",
+    "Cancel" : "Bekor qilish",
     "Accounts" : "Akkaunt",
-    "General" : "General",
+    "General" : "Umumiy",
     "List" : "Ro`yxat",
     "Register" : "Roʻyxatdan oʻtish",
     "About" : "About",
     "Archive" : "Arxiv",
-    "Delete" : "Delete",
-    "Search" : "Search",
+    "Delete" : "O'chirish",
+    "Search" : "Qidirish",
     "Send" : "Send",
     "Refresh" : "Refresh",
     "From" : "Dan",
@@ -41,13 +41,12 @@ OC.L10N.register(
     "Accept" : "Qabul qiling",
     "Decline" : "Rad etish",
     "More options" : "Boshqa variantlar",
-    "Remove" : "Remove",
+    "Remove" : "O'chirish",
     "email" : "email",
     "Other" : "Boshqa",
     "Translate" : "Tarjima",
     "Move" : "Move",
     "Remove {email}" : " {email} ni o'chirish",
-    "Quota" : "kvota",
     "Folder name" : "Jild nomi",
     "Saving" : "Saving",
     "Delete folder" : "Jildni o'chirish",
@@ -55,7 +54,7 @@ OC.L10N.register(
     "Subscribed" : "Obuna boʻlgan",
     "Reply" : "Javob bering",
     "Add" : "Add",
-    "Close" : "Close",
+    "Close" : "Yopish",
     "Date" : "Sana",
     "Tags" : "Tags",
     "Last 7 days" : "Oxirgi 7 kun",
