@@ -124,6 +124,7 @@ class MessagesController extends Controller {
 	 * @param int $cursor
 	 * @param string $filter
 	 * @param int|null $limit
+	 * @param string|null $v Cache buster version to guarantee unique urls (will trigger HTTP caching if set)
 	 *
 	 * @return JSONResponse
 	 *
@@ -134,7 +135,8 @@ class MessagesController extends Controller {
 	public function index(int $mailboxId,
 		?int $cursor = null,
 		?string $filter = null,
-		?int $limit = null): JSONResponse {
+		?int $limit = null,
+		?string $v = null): JSONResponse {
 		try {
 			$mailbox = $this->mailManager->getMailbox($this->currentUserId, $mailboxId);
 			$account = $this->accountService->find($this->currentUserId, $mailbox->getAccountId());
@@ -145,16 +147,20 @@ class MessagesController extends Controller {
 		$this->logger->debug("loading messages of mailbox <$mailboxId>");
 
 		$order = $this->preferences->getPreference($this->currentUserId, 'sort-order', 'newest') === 'newest' ? 'DESC': 'ASC';
-		return new JSONResponse(
-			$this->mailSearch->findMessages(
-				$account,
-				$mailbox,
-				$order,
-				$filter === '' ? null : $filter,
-				$cursor,
-				$limit
-			)
+		$messages = $this->mailSearch->findMessages(
+			$account,
+			$mailbox,
+			$order,
+			$filter === '' ? null : $filter,
+			$cursor,
+			$limit
 		);
+
+		$response = new JSONResponse($messages);
+		if ($v !== null && $v !== '') {
+			$response->cacheFor(7 * 24 * 3600, false, true);
+		}
+		return $response;
 	}
 
 	/**
